@@ -35,6 +35,7 @@
 #include <memory>
 #include "Host/host.h"
 #include "KeypointList.h"
+#include "ZoomConstraint.h"
 
 namespace cimg_library
 {
@@ -55,6 +56,7 @@ public:
   bool isAtFullZoom() const;
   void getPositionStringCorrection(double & xFactor, double & yFactor) const;
   double currentZoomFactor() const;
+  double defaultZoomFactor() const;
   void updateVisibleRect();
   void centerVisibleRect();
   void setPreviewImage(const cimg_library::CImg<float> & image);
@@ -75,6 +77,9 @@ public:
     KeypointMouseReleaseEvent = 2
   };
 
+  void setZoomConstraint(ZoomConstraint constraint);
+  ZoomConstraint zoomConstraint() const;
+
 protected:
   void resizeEvent(QResizeEvent *) override;
   void timerEvent(QTimerEvent *) override;
@@ -122,7 +127,6 @@ private:
   void paintPreview(QPainter &);
   void paintOriginalImage(QPainter &);
   void getOriginalImageCrop(cimg_library::CImg<float> & image);
-  void updateCachedOriginalImageCrop();
   void updateOriginalImagePosition();
   void updateErrorImage();
 
@@ -133,12 +137,12 @@ private:
   QPointF pointInWidgetToKeypointPosition(const QPoint &) const;
 
   QSize originalImageCropSize();
-  double defaultZoomFactor() const;
   void saveVisibleCenter();
   cimg_library::CImg<float> * _image;
   cimg_library::CImg<float> * _savedPreview;
   QSize _fullImageSize;
   double _currentZoomFactor;
+  ZoomConstraint _zoomConstraint;
 
   /*
    * (0) for a 1:1 preview
@@ -187,8 +191,6 @@ private:
   QSize _originalImageSize;
   QSize _originaImageScaledSize;
   bool _rightClickEnabled;
-  std::unique_ptr<cimg_library::CImg<float>> _cachedOriginalImage;
-  PreviewRect _cachedOriginalImagePosition;
   QString _errorMessage;
   QString _overlayMessage;
   QImage _errorImage;
